Black-Box Optimization (BBO)
============================

No Free Lunch Theorems (NFL)
----------------------------

As mathematically proved in , *"for any algorithm, any elevated performance over one class of problems is offset
by performance over another class."*

Curse of Dimensionality for Large-Scale BBO (LSBBO)
---------------------------------------------------

POPulation-based OPtimization/Search (POP)
------------------------------------------

General-Purpose Optimization Algorithms
---------------------------------------

*"Given the abundance of black-box optimization algorithms and of optimization problems, how can best match
algorithms to problems."*
